| Safe Haskell | Safe |
|---|---|
| Language | Haskell2010 |
SSTG.Core.Execution.Naming
Description
Naming Module
Documentation
freshName :: NameSpace -> [Name] -> Name Source #
Fresh Name given a list of Names that acts as conflicts. The fresh
Names generated in this manner are prefixed with "fs?", which is not a
valid identifier in Haskell, but okay in SSTG. we also specify the
NameSpace under which the Name will be generated. This will generally
be VarNSpace in actual usage.